==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/cs/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Uživatel zrušil žádost o položku na webu',
    'a_user_requested' => 'Uživatel požádal o položku na webu',
    'accessory_name' => 'Název příslušenství:',
    'additional_notes' => 'Další Poznámky:',
    'admin_has_created' => 'Administrátor pro vás vytvořil účet na stránce :web.',
    'asset' => 'Majetek:',
    'asset_name' => 'Název majetku:',
    'asset_requested' => 'Požadovaný majetek',
    'asset_tag' => 'Označení majetku:',
    'assigned_to' => 'Přiděleno',
    'best_regards' => 'S pozdravem,',
    'canceled' => 'Zrušeno:',
    'checkin_date' => 'Datum převzetí:',
    'checkout_date' => 'Datum vydání:',
    'click_to_confirm' => 'Kliknutím na následující odkaz potvrdíte váš účet pro :web:',
    'click_on_the_link_accessory' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi příslušné příslušenství.',
    'click_on_the_link_asset' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi daný produkt.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Aktuální množství',
    'Days' => 'Dní',
    'days' => 'Dní',
    'expecting_checkin_date' => 'Očekávané datum převzetí:',
    'expires' => 'Vyprší',
    'Expiring_Assets_Report' => 'Hlášení o končících zárukách majetku.',
    'Expiring_Licenses_Report' => 'Hlášení o končící platnosti licencí.',
    'hello' => 'Dobrý den',
    'hi' => 'Ahoj',
    'i_have_read' => 'Přečetl/a jsem si podmínky používání, souhlasím s pravidel používání a obdržel jsem tuto položku.',
    'item' => 'Položka:',
    'Item_Request_Canceled' => 'Požadavek na položku zrušen',
    'Item_Requested' => 'Požadavek na položku',
    'link_to_update_password' => 'Klepnutím na následující odkaz aktualizujte své heslo pro :web:',
    'login_first_admin' => 'Přihlaste se k nové instalaci Snipe-IT pomocí níže uvedených pověření:',
    'login' => 'Uživatelské jméno:',
    'Low_Inventory_Report' => 'Hlášení o nízkých zásobách',
    'min_QTY' => 'Minimální množství',
    'name' => 'Položka',
    'new_item_checked' => 'Nová položka byla odevzdána pod vaším jménem, podrobnosti jsou uvedeny níže.',
    'password' => 'Heslo:',
    'password_reset' => 'Resetování hesla',

    'read_the_terms' => 'Prosím přečtěte si níže uvedené podmínky použití.',
    'read_the_terms_and_click' => 'Přečtěte si prosím níže uvedené podmínky použití a klikněte na odkaz v dolní části, abyste potvrdili, že jste si přečetli a souhlasili s podmínkami používání, a že jste obdrželi majetek.',
    'requested' => 'Zažádáno:',
    'reset_link' => 'Váš odkaz pro resetování hesla',
    'reset_password' => 'Pro zresetování vašeho hesla klikněte na odkaz:',
    'serial' => 'Sériové číslo',
    'supplier' => 'Dodavatelé',
    'tag' => 'Značka',
    'test_email' => 'Testovací email od Snipe-IT',
    'test_mail_text' => 'Toto je test ze systému Snipe-IT Asset Management System. Pokud jste ho dostali, email funguje :)',
    'the_following_item' => 'Následující položka byla převzata: ',
    'low_inventory_alert' => 'Je zde :count položka která je pod minimálním stavem nebo brzy bude.|Jsou zde :count položky které jsou pod minimálním stavem nebo brzy budou.',
    'assets_warrantee_alert' => 'Je zde :count majetek se zárukou končící v následujících :threshold dnech.|Jsou zde :count majetky se zárukou končící v následujících :threshold dnech.',
    'license_expiring_alert' => 'Je zde :count licence, které končí platnost v příštích :threshold dnech.|Jsou zde :count licence, kterým končí platnost v příštích :threshold dnech.',
    'to_reset' => 'Pro resetování vašeho hesla vyplňte tento formulář:',
    'type' => 'Typ',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Uživatel',
    'username' => 'Uživatelské jméno',
    'welcome' => 'Vítej uživateli :name',
    'welcome_to' => 'Vítejte na :web!',
    'your_credentials' => 'Vaše pověření Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/cs/mail.php <==
<?php

return [
    'a_user_canceled' => 'Uživatel zrušil žádost o položku na webu',
    'a_user_requested' => 'Uživatel požádal o položku na webu',
    'accessory_name' => 'Název příslušenství:',
    'additional_notes' => 'Další Poznámky:',
    'admin_has_created' => 'Administrátor pro vás vytvořil účet na stránce :web.',
    'asset' => 'Majetek:',
    'asset_name' => 'Název majetku:',
    'asset_requested' => 'Požadovaný majetek',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Přiděleno',
    'best_regards' => 'S pozdravem,',
    'canceled' => 'Zrušeno:',
    'checkin_date' => 'Datum převzetí:',
    'checkout_date' => 'Datum vydání:',
    'click_to_confirm' => 'Kliknutím na následující odkaz potvrdíte váš účet pro :web:',
    'click_on_the_link_accessory' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi příslušné příslušenství.',
    'click_on_the_link_asset' => 'Kliknutím na odkaz v dolní části potvrďte, že jste obdrželi daný produkt.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Aktuální množství',
    'Days' => 'Dní',
    'days' => 'Dní',
    'expecting_checkin_date' => 'Očekávané datum převzetí:',
    'expires' => 'Vyprší',
    'Expiring_Assets_Report' => 'Hlášení o končících zárukách majetku.',
    'Expiring_Licenses_Report' => 'Hlášení o končící platnosti licencí.',
    'hello' => 'Dobrý den',
    'hi' => 'Ahoj',
    'i_have_read' => 'Přečetl/a jsem si podmínky používání, souhlasím s pravidel používání a obdržel jsem tuto položku.',
    'item' => 'Položka:',
    'Item_Request_Canceled' => 'Požadavek na položku zrušen',
    'Item_Requested' => 'Požadavek na položku',
    'link_to_update_password' => 'Klepnutím na následující odkaz aktualizujte své heslo pro :web:',
    'login_first_admin' => 'Přihlaste se k nové instalaci Snipe-IT pomocí níže uvedených pověření:',
    'login' => 'Uživatelské jméno:',
    'Low_Inventory_Report' => 'Hlášení o nízkých zásobách',
    'min_QTY' => 'Minimální množství',
    'name' => 'Položka',
    'new_item_checked' => 'Nová položka byla odevzdána pod vaším jménem, podrobnosti jsou uvedeny níže.',
    'password' => 'Heslo:',
    'password_reset' => 'Resetování hesla',

    'read_the_terms' => 'Prosím přečtěte si níže uvedené podmínky použití.',
    'read_the_terms_and_click' => 'Přečtěte si prosím níže uvedené podmínky použití a klikněte na odkaz v dolní části, abyste potvrdili, že jste si přečetli a souhlasili s podmínkami používání, a že jste obdrželi majetek.',
    'requested' => 'Zažádáno:',
    'reset_link' => 'Váš odkaz pro resetování hesla',
    'reset_password' => 'Pro zresetování vašeho hesla klikněte na odkaz:',
    'serial' => 'Sériové číslo',
    'supplier' => 'Dodavatelé',
    'tag' => 'Značka',
    'test_email' => 'Testovací email od Snipe-IT',
    'test_mail_text' => 'Toto je test ze systému Snipe-IT Asset Management System. Pokud jste ho dostali, email funguje :)',
    'the_following_item' => 'Následující položka byla převzata: ',
    'low_inventory_alert' => 'Je zde :count položka která je pod minimálním stavem nebo brzy bude.|Jsou zde :count položky které jsou pod minimálním stavem nebo brzy budou.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Je zde :count licence, které končí platnost v příštích :threshold dnech.|Jsou zde :count licence, kterým končí platnost v příštích :threshold dnech.',
    'to_reset' => 'Pro resetování vašeho hesla vyplňte tento formulář:',
    'type' => 'Typ',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Uživatel',
    'username' => 'Uživatelské jméno',
    'welcome' => 'Vítej uživateli :name',
    'welcome_to' => 'Vítejte na :web!',
    'your_credentials' => 'Vaše pověření Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
